summaryrefslogtreecommitdiffstats
path: root/kplato/kptdatetable.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptdatetable.cc')
-rw-r--r--kplato/kptdatetable.cc26
1 files changed, 13 insertions, 13 deletions
diff --git a/kplato/kptdatetable.cc b/kplato/kptdatetable.cc
index afa06591..c4d8022d 100644
--- a/kplato/kptdatetable.cc
+++ b/kplato/kptdatetable.cc
@@ -32,7 +32,7 @@
#include <tqpainter.h>
#include <tqdialog.h>
#include <assert.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqvaluelist.h>
#include <kglobalsettings.h>
@@ -88,7 +88,7 @@ DateTable::DateTable(TQWidget *parent, TQDate date_, const char* name, WFlags f)
setFontSize(10);
if(!date_.isValid()) {
kdError() <<k_funcinfo<<"Given date is invalid, using current date." << endl;
- date_=TQDate::tqcurrentDate();
+ date_=TQDate::currentDate();
}
setFocusPolicy( TQ_StrongFocus );
setNumCols(7+m_dateStartCol); // 7 days a week + maybe 1 for weeknumbers
@@ -175,7 +175,7 @@ void DateTable::paintWeekNumber(TQPainter *painter, int row) {
painter->drawRect(0, 0, w, h);
painter->setPen(KGlobalSettings::textColor());
- painter->drawText(0, 0, w, h-1, AlignCenter, TQString("%1").tqarg(m_weeks[row].first), -1, &rect);
+ painter->drawText(0, 0, w, h-1, AlignCenter, TQString("%1").arg(m_weeks[row].first), -1, &rect);
painter->setPen(colorLine);
painter->moveTo(w-1, 0);
painter->lineTo(w-1, h-1);
@@ -232,7 +232,7 @@ void DateTable::paintDay(TQPainter *painter, int row, int col) {
painter->lineTo(w-1, h-1);
}
// then paint square if current date
- if (d == TQDate::tqcurrentDate()) {
+ if (d == TQDate::currentDate()) {
painter->setPen(colorLine);
painter->drawRect(1, 1, w-2, h-2);
}
@@ -317,7 +317,7 @@ void DateTable::keyPressEvent( TQKeyEvent *e ) {
return;
}
if ( e->key() == TQt::Key_N ) {
- setDate(TQDate::tqcurrentDate());
+ setDate(TQDate::currentDate());
return;
}
if ( e->key() == TQt::Key_Control ) {
@@ -353,7 +353,7 @@ void DateTable::setFontSize(int size) {
maxCell.setHeight(TQMAX(maxCell.height(), rect.height()));
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
+ rect=metrics.boundingRect(TQString::fromLatin1("88"));
maxCell.setWidth(TQMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(TQMAX(maxCell.height()+4, rect.height()));
}
@@ -527,7 +527,7 @@ bool DateTable::selectDate(const TQDate& date_) {
return true;
}
-bool DateTable::setDate(const TQDate& date_, bool tqrepaint) {
+bool DateTable::setDate(const TQDate& date_, bool repaint) {
//kdDebug()<<k_funcinfo<<"date="<<date_.toString()<<endl;
bool changed=false;
TQDate temp;
@@ -562,7 +562,7 @@ bool DateTable::setDate(const TQDate& date_, bool tqrepaint) {
m_selectedDates.insert(date);
}*/
numDaysPrevMonth=temp.daysInMonth();
- if(changed && tqrepaint) {
+ if(changed && repaint) {
repaintContents(false);
}
if (m_enabled)
@@ -582,12 +582,12 @@ void DateTable::focusOutEvent( TQFocusEvent *e ) {
TQGridView::focusOutEvent( e );
}
-TQSize DateTable::tqsizeHint() const {
+TQSize DateTable::sizeHint() const {
if(maxCell.height()>0 && maxCell.width()>0) {
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- //kdDebug() << "DateTable::tqsizeHint: obscure failure - " << endl;
+ //kdDebug() << "DateTable::sizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
@@ -794,7 +794,7 @@ DateInternalMonthPicker::DateInternalMonthPicker
}
TQSize
-DateInternalMonthPicker::tqsizeHint() const
+DateInternalMonthPicker::sizeHint() const
{
return TQSize((max.width()+6)*numCols()+2*frameWidth(),
(max.height()+6)*numRows()+2*frameWidth());
@@ -894,7 +894,7 @@ DateInternalMonthPicker::contentsMouseMoveEvent(TQMouseEvent *e)
updateCell( row, col /*, false */ ); // mark the new active cell
}
}
- if ( tmpRow > -1 ) // tqrepaint the former active cell
+ if ( tmpRow > -1 ) // repaint the former active cell
updateCell( tmpRow, tmpCol /*, true */ );
}
}
@@ -1053,7 +1053,7 @@ int
PopupFrame::exec(TQPoint pos)
{
popup(pos);
- tqrepaint();
+ repaint();
tqApp->enter_loop();
hide();
return result;